#
# spec file for package qiv
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           qiv
Version:        2.3.2
Release:        bp155.2.13
Summary:        A gdk/imlib based image viewer
License:        GPL-2.0-or-later
Group:          Productivity/Graphics/Viewers
Url:            https://spiegl.de/qiv/
Source0:        https://spiegl.de/qiv/download/qiv-%{version}.tgz
BuildRequires:  file-devel
BuildRequires:  gtk2-devel
BuildRequires:  imlib2-devel
BuildRequires:  libexif-devel
BuildRequires:  libjpeg8-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libtiff-devel
BuildRequires:  update-desktop-files
# imlib itself only recommends that but we actually need them to
# load images
Requires:       imlib2-loaders

%description
The "Quick Image Viewer" (qiv) is a GDK/Imlib image viewer similar to
viewers like xv or xloadimage. qiv features setting an image as an
x11 background with a user-definable background color, fullscreen
viewing, a screensaver mode, brightness/contrast/gamma correction,
real transparency, zoom and slideshow.

It creates only one window, containing only the image to view.

%prep
%setup -q
sed -i 's/-O2/$(RPM_OPT_FLAGS)/' Makefile

# Remove exec bit from contrib scripts to avoid additional dependencies
chmod -x contrib/*

%build
make %{?_smp_mflags}

%install
install -Dpm 755 qiv %{buildroot}%{_bindir}/qiv
install -Dpm 644 qiv.1 %{buildroot}%{_mandir}/man1/qiv.1
install -Dpm 0644 qiv.png %{buildroot}%{_datadir}/pixmaps/qiv.png
install -Dpm 0644 qiv.desktop %{buildroot}%{_datadir}/applications/qiv.desktop
%suse_update_desktop_file qiv

%files
%doc README README.COPYING README.TODO contrib
%{_bindir}/qiv
%{_mandir}/man1/qiv.1%{ext_man}
%{_datadir}/pixmaps/qiv.png
%{_datadir}/applications/qiv.desktop

%changelog
* Sat Mar  3 2018 jengelh@inai.de
- Ensure neutrality of description. Trim manual from description.
  In fact, switch the description to the one used by qiv-1.6.spec
  directly from upstream. (This is apparently the only file by
  upstream to ever have contained a description.)
* Sun Feb 18 2018 avindra@opensuse.org
- update to version 2.3.2:
  * fix: window sometimes recentered, when moved around with mouse
  * fix Makefile for cross-compiling: Make pkg-config substitutable
  * add specfile to build rpm for CentOS
  * add option --trashbin to use trash bin instead of .qiv-trash
    when deleting images
  * add ability (and options) to display JPEG comments
  * more sophisticated exiftool call in qiv-command example
  * fix inconsistent fixed-zoom behaviour
  * Don't try to rotate if file is not an image
  * get rid of some more XID collisions
  * Fix occasionally erratic behaviour of qiv statusbar
  * Fix xpm autodetection with libmagic
  * Fix small artefacts in pictures which might happen when running
    remote over slow link
  * update image after it is exposed in window mode
  * fix broken "-no-filter" option libmagic filter now works on
    symlinks
  * fix linking order in "make debug", did not work in some newer
    gcc versions
  * turn on EXIF autorotation by default
  * Add option to sort files by modification time.
  * In case of "watch" option, check image only every 1/10 sec,
    instead of every 200us. This was way too short for devices like
    RasPi etc.
  * Leave jumping mode on invalid input and process input key as if
    it was entered in non jumping mode
- cleanup with spec-cleaner
* Sat Feb 21 2015 benoit.monin@gmx.fr
- update to version 2.3.1:
  * add libXext to libraries for linking in Makefile
- additionnal changes from version 2.3.0:
  * unicode fix for gps2url.py
  * Some cleanup in the debian subdir
  * Add desktop integration. Add gps2url.py script
  * browse option now starts with first picture on command line
  * fix direction of scrollwheel for next/previous image
  * center mouse cursor position in magnifying window
  * external script gps2url.py to extract GPS coordinates from an
    image and call firefox with google maps url
  * integration into qiv-command.example
  * update COPYING and optimize libmagic calls
  * improve display of exif GPS tags
  * new option --vikeys to allow for vi-style movement
  * disable screensaver and DPMS during slideshow
  * improvements to qiv-command.example
  * fix possible segfaults when dealing with corrupt embedded color
    profiles
  * do not segfault when "browse" option is called without a
    further argument
  * fix magnifying window. Zoom factor of magnifying window can be
    changed by +/- keys
  * fix missing #ifdef HAVE_EXIF for exif header file
  * get rid of XID collision
  * code cleanup, mostly exif
  * Make conditional rotate leave images that fit alone
  * Add --followlinks option to all symlinks to dirs
  * Fixed inconsistency with rotate option, add conditional
    rotation
  * Add runtime option to display Exif information
  * Add runtime option to toggle grab mode
  * Add support for embedded color profiles in tiff
  * Better fullscreen handling with multi monitors
    Xinerama is no longer needed
  * Notice when a mouse click makes the display-text disappear
  * Center display-text on the preferred xinerama screen
  * Simplify image-move checking code and allow it to move an image
    farther
  * Replace GDK_<keyname> with GDK_KEY_<keyname>
  * Add support for embedded color profiles in jpg
  * replace gdk_window_set_icon with gdk_window_set_icon_list
  * add color profile support via lcms2
  * when using "--watch" option, make sure pic is not reloaded
    while still written
- drop patches merged upstream:
  * magic-optimization.patch
  * update-copying.patch
- drop qiv-2.2.4-fix-bashisms.patch:
  shebang of qiv-command.example has been changed to /bin/bash
- remove libXinerama-devel from BuildRequires: not needed anymore
- add new build dependencies:
  * libjpeg8-devel
  * liblcms2-devel
  * libtiff-devel
  * update-desktop-files
- remove exec bit from contrib scripts to avoid additional
  dependencies
- install icon and desktop file
- install contrib scripts with the documentation
* Wed Nov 19 2014 Led <ledest@gmail.com>
- fix bashisms in qiv-command.example script
- add patches:
  * qiv-2.2.4-fix-bashisms.patch
* Mon Feb 18 2013 jslaby@suse.com
- magic-optimization.patch: optimize libmagic invocation
  (workaround for bnc#804323)
- update-copying.patch: update README.COPYING to have correct
  address
* Tue Feb 21 2012 lnussel@suse.de
- BuildRequire libXinerama-devel to fix build after xorg split
* Mon Nov 28 2011 jslaby@suse.de
- new version 2.2.4
  * qiv-command: more examples
  * only center image upon reload when center option is active
  * make gdk options work again (e.g. --display)
  * Do not follow symlinked directories, when using recursivedir option
  * Add option to change cycle behavior after last picture
  * Images were displayed twice when using --browse option
  * Fix inconsistent behavior when using -x/-y/-z option
* Tue May 11 2010 lnussel@suse.de
- new version 2.2.3
  * add 'Q' icon in qiv-window
  * bring back scrollwheel functionality
  * change loading of images from imlib2_loader to
    pixbuf_loader. Adds support for additional file
    types, e.g. pcx, ico, svg, wmf and better handling
    of transparency.
  * use gdk_pixbuf to autorotate with EXIF tags instead
    of libexif.
  * Resetting the image (pressing return) no longer
    destroys "transparency checkboard"
  * new option to start with default rotation
* Thu Jan  7 2010 lnussel@suse.de
- require imlib2-loaders
* Mon Dec 28 2009 vuntz@opensuse.org
- Update to version 2.2.2:
  + fix -x (root window needs colormap)
  + patch pango code to avoid garbled output of F1
  + fix wrong image size after autorotating
- Changes from version 2.2.1:
  + recognize changed files, using --slideshow and --watch
  + sanitize infotextdisplay
  + check EXIF tags only after successful file loading
  + shuffle now implies not to sort filenames
  + fix autorotate with EXIF-tag
  + avoid crash calling qiv -x without argument
  + fix behaviour of "recursivedir" switch
  + migrated gdk_draw_text() to gdk_draw_layout()
  +fixing wrong display of utf-8 filenames
- Changes from version 2.2:
  + migration from imlib1 to imlib2
- Changes from version 2.1:
  + removed obsoleted GDK_WA_WMCLASS
  + added patches from debian
  + remove xscreensaver left overs from Makefiles
  + added autorotate patch (using libexif)
  + display initial autorotation in status bar, option "autorotate"
  + patch to detect image types using libmagic
  + added GDK_ENTER_NOTIFY_MASK|GDK_LEAVE_NOTIFY_MASK in image.c
  + removed TGA and XBM because not supported by imlib anymore
  + exit on unmapped mouse events
  + browse option -B, useful when launching qiv from a file manager
  + patch to prevent segfault on amd64
- Changes imlib-devel BuildRequires to imlib2-devel.
- Add file-devel, libexif-devel BuildRequires.
- Remove GDK_WA_WMCLASS workaround: not needed anymore.
- Drop qiv-2.1-pre12.patch: fixed upstream.
* Wed Dec 12 2007 rguenther@suse.de
- fix possible buffer overflow
* Tue Aug 21 2007 bk@suse.de
- initial version
